@@ -4,13 +4,13 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/scaleway/scaleway-cli/v2/internal/core"
-	"github.com/scaleway/scaleway-cli/v2/internal/namespaces"
+	"github.com/scaleway/scaleway-cli/v2/commands"
+	"github.com/scaleway/scaleway-cli/v2/core"
 )
 
 func Test_MainUsage(t *testing.T) {
 	t.Run("usage", core.Test(&core.TestConfig{
-		Commands: namespaces.GetCommands(),
+		Commands: commands.GetCommands(),
 		Cmd:      "scw -h",
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(0),
@@ -27,7 +27,7 @@ func Test_AllUsage(t *testing.T) {
 		"autocomplete script": true,
 	}
 
-	for _, cmd := range namespaces.GetCommands().GetAll() {
+	for _, cmd := range commands.GetCommands().GetAll() {
 		commandLine := cmd.GetCommandLine("scw")
 		commandLine = strings.TrimPrefix(commandLine, "scw ")
 		if _, exists := excludedCommands[commandLine]; exists || cmd.Hidden {
@@ -35,7 +35,7 @@ func Test_AllUsage(t *testing.T) {
 		}
 
 		t.Run(commandLine+" usage", core.Test(&core.TestConfig{
-			Commands: namespaces.GetCommands(),
+			Commands: commands.GetCommands(),
 			Cmd:      "scw " + commandLine + " -h",
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
