@@ -21,7 +21,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "interrupt",
 				Verb:      "error",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return nil, &interactive.InterruptError{}
 				},
 			},
@@ -38,7 +38,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "code",
 				Verb:      "error",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return nil, &core.CliError{Code: 99}
 				},
 			},
@@ -55,7 +55,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "empty",
 				Verb:      "error",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return nil, &core.CliError{Code: 99, Empty: true}
 				},
 			},
@@ -75,7 +75,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "empty",
 				Verb:      "error",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return nil, &core.CliError{Code: 99, Empty: true}
 				},
 			},
@@ -95,7 +95,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "empty",
 				Verb:      "success",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return &core.SuccessResult{
 						Empty:    true,
 						Message:  "dummy",
@@ -118,7 +118,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "empty",
 				Verb:      "success",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return &core.SuccessResult{
 						Empty:    true,
 						Message:  "dummy",
@@ -141,7 +141,7 @@ func TestInterruptError(t *testing.T) {
 				Resource:  "empty",
 				Verb:      "success",
 				ArgsType:  reflect.TypeOf(args.RawArgs{}),
-				Run: func(_ context.Context, _ interface{}) (i interface{}, e error) {
+				Run: func(_ context.Context, _ any) (i any, e error) {
 					return []int(nil), nil
 				},
 				AllowAnonymousClient: true,
