@@ -11,5 +11,6 @@ func IsNotFoundError(err error) bool {
 	notFoundError := &scw.ResourceNotFoundError{}
 	responseError := &scw.ResponseError{}
 
-	return errors.As(err, &responseError) && responseError.StatusCode == http.StatusNotFound || errors.As(err, &notFoundError)
+	return errors.As(err, &responseError) && responseError.StatusCode == http.StatusNotFound ||
+		errors.As(err, &notFoundError)
 }
