@@ -14,13 +14,21 @@ func GetCommands() *core.Commands {
 		serverWaitCommand(),
 	))
 
+	cmds.MustFind("apple-silicon").Groups = []string{"baremetal"}
+
 	human.RegisterMarshalerFunc(applesilicon.ServerTypeCPU{}, cpuMarshalerFunc)
 	human.RegisterMarshalerFunc(applesilicon.ServerTypeDisk{}, diskMarshalerFunc)
 	human.RegisterMarshalerFunc(applesilicon.ServerTypeMemory{}, memoryMarshalerFunc)
 	human.RegisterMarshalerFunc(applesilicon.OS{}, OSMarshalerFunc)
 
-	human.RegisterMarshalerFunc(applesilicon.ServerStatus(""), human.EnumMarshalFunc(serverStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(applesilicon.ServerTypeStock(""), human.EnumMarshalFunc(serverTypeStockMarshalSpecs))
+	human.RegisterMarshalerFunc(
+		applesilicon.ServerStatus(""),
+		human.EnumMarshalFunc(serverStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		applesilicon.ServerTypeStock(""),
+		human.EnumMarshalFunc(serverTypeStockMarshalSpecs),
+	)
 
 	cmds.MustFind("apple-silicon", "server", "create").Override(serverCreateBuilder)
 	cmds.MustFind("apple-silicon", "server", "reboot").Override(serverRebootBuilder)
