@@ -9,6 +9,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/baremetal/v1"
 	flexibleip "github.com/scaleway/scaleway-cli/v2/internal/namespaces/flexibleip/v1alpha1"
 	baremetalSDK "github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
+	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
 func Test_CreateFlexibleIPInteractive(t *testing.T) {
@@ -24,8 +25,8 @@ func Test_CreateFlexibleIPInteractive(t *testing.T) {
 			func(ctx *core.BeforeFuncCtx) error {
 				api := baremetalSDK.NewAPI(ctx.Client)
 				server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-					OfferName: offerName,
-					Zone:      region,
+					OfferName: offerNameNVME,
+					Zone:      scw.Zone(zone),
 				})
 				if server.Stock != baremetalSDK.OfferStockAvailable {
 					return errors.New("offer out of stock")
@@ -33,15 +34,15 @@ func Test_CreateFlexibleIPInteractive(t *testing.T) {
 
 				return nil
 			},
-			createServerAndWaitDefault("Server"),
+			createServerAndWait(),
 		),
-		Cmd: "scw baremetal server add-flexible-ip {{ .Server.ID }}",
+		Cmd: "scw baremetal server add-flexible-ip {{ .Server.ID }} zone=" + zone,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 		),
 		AfterFunc: core.AfterFuncCombine(
-			deleteServerDefault("Server"),
-			core.ExecAfterCmd("scw fip ip delete {{ .CmdResult.ID }}"),
+			deleteServer("Server"),
+			core.ExecAfterCmd("scw fip ip delete {{ .CmdResult.ID }} zone="+zone),
 		),
 		PromptResponseMocks: promptResponse,
 	}))
@@ -57,8 +58,8 @@ func Test_CreateFlexibleIP(t *testing.T) {
 			func(ctx *core.BeforeFuncCtx) error {
 				api := baremetalSDK.NewAPI(ctx.Client)
 				server, _ := api.GetOfferByName(&baremetalSDK.GetOfferByNameRequest{
-					OfferName: offerName,
-					Zone:      region,
+					OfferName: offerNameNVME,
+					Zone:      scw.Zone(zone),
 				})
 				if server.Stock != baremetalSDK.OfferStockAvailable {
 					return errors.New("offer out of stock")
@@ -66,15 +67,15 @@ func Test_CreateFlexibleIP(t *testing.T) {
 
 				return nil
 			},
-			createServerAndWaitDefault("Server"),
+			createServerAndWait(),
 		),
-		Cmd: "scw baremetal server add-flexible-ip {{ .Server.ID }} ip-type=IPv4",
+		Cmd: "scw baremetal server add-flexible-ip {{ .Server.ID }} ip-type=IPv4 zone=" + zone,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 		),
 		AfterFunc: core.AfterFuncCombine(
-			deleteServerDefault("Server"),
-			core.ExecAfterCmd("scw fip ip delete {{ .CmdResult.ID }}"),
+			deleteServer("Server"),
+			core.ExecAfterCmd("scw fip ip delete {{ .CmdResult.ID }} zone="+zone),
 		),
 	}))
 }
