@@ -52,6 +52,12 @@ func GetCommands() *core.Commands {
 	cmds.MustFind("iam", "policy", "create").Override(iamPolicyCreateBuilder)
 	cmds.MustFind("iam", "policy", "get").Override(iamPolicyGetBuilder)
 
+	iamCmd := cmds.MustFind("iam", "api-key", "get")
+	iamCmd.ArgsType = iamApiKeyCustomBuilder.argType
+	iamCmd.ArgSpecs = iamApiKeyCustomBuilder.argSpecs
+	iamCmd.Run = iamApiKeyCustomBuilder.run
+	human.RegisterMarshalerFunc(apiKeyResponse{}, apiKeyMarshalerFunc)
+
 	return cmds
 }
 
@@ -79,7 +85,7 @@ func setOrganizationDefaultValue(c *core.Command) *core.Command {
 	return c
 }
 
-func InitWithSSHKeyRun(ctx context.Context, _ interface{}) (i interface{}, e error) {
+func InitWithSSHKeyRun(ctx context.Context, _ any) (i any, e error) {
 	// Get default local SSH key
 	var shortenedFilename string
 	var err error
