@@ -37,7 +37,6 @@ func imagesMarshalerFunc(i any, _ *human.MarshalOpt) (string, error) {
 		ID               string
 		Name             string
 		State            instance.ImageState
-		Public           bool
 		Zone             scw.Zone
 		Volumes          []scw.Size
 		ServerName       string
@@ -72,7 +71,6 @@ func imagesMarshalerFunc(i any, _ *human.MarshalOpt) (string, error) {
 			ID:               image.ID,
 			Name:             image.Name,
 			State:            image.State,
-			Public:           image.Public,
 			Zone:             image.Zone,
 			Volumes:          volumes,
 			ServerName:       image.ServerName,
@@ -167,13 +165,19 @@ type imageListItem struct {
 // A call to GetServer(..) with the ID contained in Image.FromServer retrieves more information about the server.
 func imageListBuilder(c *core.Command) *core.Command {
 	type customListImageRequest struct {
-		*instance.ListImagesRequest
+		Zone           scw.Zone `json:"-"`
+		PerPage        *uint32  `json:"-"`
+		Page           *int32   `json:"-"`
+		Name           *string  `json:"-"`
+		Arch           *string  `json:"-"`
+		Tags           *string  `json:"-"`
 		OrganizationID *string
 		ProjectID      *string
 	}
 
 	renameOrganizationIDArgSpec(c.ArgSpecs)
 	renameProjectIDArgSpec(c.ArgSpecs)
+	c.ArgSpecs.DeleteByName("public")
 
 	c.ArgsType = reflect.TypeOf(customListImageRequest{})
 
@@ -181,14 +185,15 @@ func imageListBuilder(c *core.Command) *core.Command {
 		// Get images
 		args := argsI.(*customListImageRequest)
 
-		if args.ListImagesRequest == nil {
-			args.ListImagesRequest = &instance.ListImagesRequest{}
+		req := &instance.ListImagesRequest{
+			Organization: args.OrganizationID,
+			Name:         args.Name,
+			Public:       scw.BoolPtr(false),
+			Arch:         args.Arch,
+			Project:      args.ProjectID,
+			Tags:         args.Tags,
 		}
 
-		req := args.ListImagesRequest
-		req.Organization = args.OrganizationID
-		req.Project = args.ProjectID
-		req.Public = scw.BoolPtr(false)
 		client := core.ExtractClient(ctx)
 		api := instance.NewAPI(client)
 		blockAPI := block.NewAPI(client)
@@ -228,7 +233,7 @@ func imageListBuilder(c *core.Command) *core.Command {
 				if volume.VolumeType == instance.VolumeVolumeTypeSbsSnapshot {
 					blockVolume, err := blockAPI.GetSnapshot(&block.GetSnapshotRequest{
 						SnapshotID: volume.ID,
-						Zone:       volume.Zone,
+						Zone:       image.Zone,
 					}, scw.WithContext(ctx))
 					if err != nil {
 						return nil, err
@@ -334,6 +339,7 @@ func imageDeleteBuilder(c *core.Command) *core.Command {
 							SnapshotID:     snapshot.ID,
 							Zone:           args.Zone,
 							TerminalStatus: &terminalStatus,
+							RetryInterval:  core.DefaultRetryInterval,
 						})
 						if err != nil {
 							return nil, err
