@@ -24,7 +24,7 @@ var hubStatusMarshalSpecs = human.EnumMarshalSpecs{
 }
 
 func hubCreateBuilder(c *core.Command) *core.Command {
-	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
 		api := iot.NewAPI(core.ExtractClient(ctx))
 
 		return api.WaitForHub(&iot.WaitForHubRequest{
