@@ -3,12 +3,9 @@ package k8s
 import (
 	"context"
 	"encoding/json"
-	"errors"
-	"fmt"
 	"reflect"
 
 	"github.com/scaleway/scaleway-cli/v2/core"
-	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/scaleway/scaleway-sdk-go/validation"
 )
 
@@ -28,39 +25,20 @@ func k8sExecCredentialCommand() *core.Command {
 }
 
 func k8sExecCredentialRun(ctx context.Context, _ any) (i any, e error) {
-	config, _ := scw.LoadConfigFromPath(core.ExtractConfigPath(ctx))
-	profileName := core.ExtractProfileName(ctx)
-
-	var token string
-	switch {
-	// Environment variable check
-	case core.ExtractEnv(ctx, scw.ScwSecretKeyEnv) != "":
-		token = core.ExtractEnv(ctx, scw.ScwSecretKeyEnv)
-	// There is no config file
-	case config == nil:
-		return nil, errors.New("config not provided")
-	// Config file with profile name
-	case config.Profiles[profileName] != nil && config.Profiles[profileName].SecretKey != nil:
-		token = *config.Profiles[profileName].SecretKey
-	// Default config
-	case config.SecretKey != nil:
-		token = *config.SecretKey
-	default:
-		return nil, errors.New("unable to find secret key")
+	secretKey, err := extractSecretKey(ctx)
+	if err != nil {
+		return nil, err
 	}
 
-	if !validation.IsSecretKey(token) {
-		return nil, fmt.Errorf(
-			"invalid secret key format '%s', expected a UUID: xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
-			token,
-		)
+	if !validation.IsSecretKey(secretKey) {
+		return nil, core.InvalidSecretKeyError(secretKey)
 	}
 
 	execCreds := ExecCredential{
 		APIVersion: "client.authentication.k8s.io/v1",
 		Kind:       "ExecCredential",
 		Status: &ExecCredentialStatus{
-			Token: token,
+			Token: secretKey,
 		},
 	}
 	response, err := json.MarshalIndent(execCreds, "", "    ")
