@@ -45,6 +45,9 @@ If the current context points to this cluster, it will be set to an empty contex
 				Short:   "Install a kubeconfig",
 			},
 		},
+
+		// avoid calling checkAPIKey (Check if API Key is about to expire)
+		DisableAfterChecks: true,
 	}
 }
 
@@ -52,11 +55,7 @@ If the current context points to this cluster, it will be set to an empty contex
 // it removes all the users, contexts and clusters that contains this ID from the file
 func k8sKubeconfigUninstallRun(ctx context.Context, argsI any) (i any, e error) {
 	request := argsI.(*k8sKubeconfigUninstallRequest)
-
-	kubeconfigPath, err := getKubeconfigPath(ctx)
-	if err != nil {
-		return nil, err
-	}
+	kubeconfigPath := getKubeconfigPath(ctx)
 
 	// if the file does not exist, the cluster is not there
 	if _, err := os.Stat(kubeconfigPath); os.IsNotExist(err) {
