@@ -17,6 +17,7 @@ import (
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/core/human"
+	"github.com/scaleway/scaleway-cli/v2/internal/editor"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
 	"github.com/scaleway/scaleway-cli/v2/internal/passwordgenerator"
 	"github.com/scaleway/scaleway-cli/v2/internal/terminal"
@@ -95,7 +96,7 @@ type rdbCreateInstanceRequestCustom struct {
 	GeneratePassword bool
 }
 
-func createInstanceResultMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func createInstanceResultMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	instanceResult := i.(CreateInstanceResult)
 
 	opt.Sections = []*human.MarshalSection{
@@ -124,7 +125,7 @@ func createInstanceResultMarshalerFunc(i interface{}, opt *human.MarshalOpt) (st
 	}, "\n\n"), nil
 }
 
-func instanceMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func instanceMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	// To avoid recursion of human.Marshal we create a dummy type
 	type tmp rdbSDK.Instance
 	instance := tmp(i.(rdbSDK.Instance))
@@ -153,7 +154,7 @@ func instanceMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error)
 	return str, nil
 }
 
-func backupScheduleMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+func backupScheduleMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	backupSchedule := i.(rdbSDK.BackupSchedule)
 
 	if opt.TableCell {
@@ -191,7 +192,7 @@ func backupScheduleMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string,
 }
 
 func instanceCloneBuilder(c *core.Command) *core.Command {
-	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
 		api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 
 		return api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
@@ -252,7 +253,15 @@ func autoCompleteDatabaseEngines(
 	prefix string,
 	request any,
 ) core.AutocompleteSuggestions {
-	req := request.(rdbCreateInstanceRequestCustom)
+	var req *rdbCreateInstanceRequestCustom
+	switch v := request.(type) {
+	case rdbCreateInstanceRequestCustom:
+		req = &v
+	case *rdbCreateInstanceRequestCustom:
+		req = v
+	default:
+		return nil
+	}
 	suggestion := core.AutocompleteSuggestions(nil)
 	client := core.ExtractClient(ctx)
 	api := rdbSDK.NewAPI(client)
@@ -304,7 +313,7 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 
 	c.ArgsType = reflect.TypeOf(rdbCreateInstanceRequestCustom{})
 
-	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
 		api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 		instance, err := api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
 			InstanceID:    respI.(CreateInstanceResult).ID,
@@ -324,7 +333,7 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 		return result, nil
 	}
 
-	c.Run = func(ctx context.Context, argsI interface{}) (interface{}, error) {
+	c.Run = func(ctx context.Context, argsI any) (any, error) {
 		client := core.ExtractClient(ctx)
 		api := rdbSDK.NewAPI(client)
 
@@ -363,7 +372,7 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 	}
 
 	// Waiting for API to accept uppercase node-type
-	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+	c.Interceptor = func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 		args := argsI.(*rdbCreateInstanceRequestCustom)
 		args.NodeType = strings.ToLower(args.NodeType)
 
@@ -374,7 +383,7 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 }
 
 func instanceGetBuilder(c *core.Command) *core.Command {
-	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+	c.Interceptor = func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 		res, err := runner(ctx, argsI)
 		if err != nil {
 			return nil, err
@@ -434,7 +443,7 @@ func instanceGetBuilder(c *core.Command) *core.Command {
 func instanceUpgradeBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("node-type").AutoCompleteFunc = autoCompleteNodeType
 
-	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
 		api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 
 		return api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
@@ -541,7 +550,7 @@ func instanceUpdateBuilder(_ *core.Command) *core.Command {
 			},
 			core.RegionArgSpec(scw.RegionFrPar, scw.RegionNlAms, scw.RegionPlWaw),
 		},
-		Run: func(ctx context.Context, args interface{}) (i interface{}, e error) {
+		Run: func(ctx context.Context, args any) (i any, e error) {
 			customRequest := args.(*rdbUpdateInstanceRequestCustom)
 
 			updateInstanceRequest := customRequest.UpdateInstanceRequest
@@ -593,7 +602,7 @@ func instanceUpdateBuilder(_ *core.Command) *core.Command {
 
 			return updateInstanceResponse, nil
 		},
-		WaitFunc: func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+		WaitFunc: func(ctx context.Context, _, respI any) (any, error) {
 			api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 
 			return api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
@@ -621,7 +630,7 @@ func instanceUpdateBuilder(_ *core.Command) *core.Command {
 }
 
 func instanceDeleteBuilder(c *core.Command) *core.Command {
-	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
 		api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 		instance, err := api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
 			InstanceID:    respI.(*rdbSDK.Instance).ID,
@@ -656,7 +665,7 @@ func instanceWaitCommand() *core.Command {
 		Verb:      "wait",
 		Groups:    []string{"workflow"},
 		ArgsType:  reflect.TypeOf(serverWaitRequest{}),
-		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+		Run: func(ctx context.Context, argsI any) (i any, err error) {
 			api := rdbSDK.NewAPI(core.ExtractClient(ctx))
 
 			return api.WaitForInstance(&rdbSDK.WaitForInstanceRequest{
@@ -862,7 +871,7 @@ func instanceConnectCommand() *core.Command {
 			},
 			core.RegionArgSpec(scw.RegionFrPar, scw.RegionNlAms),
 		},
-		Run: func(ctx context.Context, argsI interface{}) (interface{}, error) {
+		Run: func(ctx context.Context, argsI any) (any, error) {
 			args := argsI.(*instanceConnectArgs)
 
 			client := core.ExtractClient(ctx)
@@ -925,3 +934,89 @@ func instanceConnectCommand() *core.Command {
 		},
 	}
 }
+
+func instanceEditSettingsCommand() *core.Command {
+	type editSettingsArgs struct {
+		InstanceID string     `arg:"positional,required"`
+		Region     scw.Region `arg:"required"`
+		Mode       editor.MarshalMode
+	}
+
+	return &core.Command{
+		Namespace: "rdb",
+		Resource:  "setting",
+		Verb:      "edit",
+		Short:     "Edit Database Instance settings in your default editor",
+		Long: `This command opens the current settings of your RDB instance in your $EDITOR.
+You can modify the values and save the file to apply the new configuration.`,
+		ArgsType: reflect.TypeOf(editSettingsArgs{}),
+		ArgSpecs: core.ArgSpecs{
+			{
+				Name:       "instance-id",
+				Short:      "ID of the instance",
+				Required:   true,
+				Positional: true,
+			},
+			editor.MarshalModeArgSpec(), // --mode=yaml|json
+			core.RegionArgSpec(scw.RegionFrPar, scw.RegionNlAms, scw.RegionPlWaw),
+		},
+		Examples: []*core.Example{
+			{
+				Short: "Edit instance settings in YAML",
+				Raw:   "scw rdb setting edit 12345678-1234-1234-1234-123456789abc --region=fr-par --mode=yaml",
+			},
+			{
+				Short: "Edit instance settings in JSON",
+				Raw:   "scw rdb setting edit 12345678-1234-1234-1234-123456789abc --region=fr-par --mode=json",
+			},
+		},
+		Run: func(ctx context.Context, argsI any) (any, error) {
+			args := argsI.(*editSettingsArgs)
+
+			client := core.ExtractClient(ctx)
+			api := rdbSDK.NewAPI(client)
+
+			instance, err := api.GetInstance(&rdbSDK.GetInstanceRequest{
+				InstanceID: args.InstanceID,
+				Region:     args.Region,
+			})
+			if err != nil {
+				return nil, err
+			}
+
+			initialRequest := &rdbSDK.SetInstanceSettingsRequest{
+				Region:     args.Region,
+				InstanceID: args.InstanceID,
+				Settings:   instance.Settings,
+			}
+
+			editedRequestRaw, err := editor.UpdateResourceEditor(
+				initialRequest,
+				&rdbSDK.SetInstanceSettingsRequest{
+					Region:     args.Region,
+					InstanceID: args.InstanceID,
+				},
+				&editor.Config{
+					PutRequest:  true,
+					MarshalMode: args.Mode,
+				},
+			)
+			if err != nil {
+				return nil, err
+			}
+
+			editedRequest := editedRequestRaw.(*rdbSDK.SetInstanceSettingsRequest)
+
+			if reflect.DeepEqual(initialRequest.Settings, editedRequest.Settings) {
+				return &core.SuccessResult{Message: "No changes detected."}, nil
+			}
+
+			_, err = api.SetInstanceSettings(editedRequest)
+			if err != nil {
+				return nil, err
+			}
+
+			return &core.SuccessResult{Message: "Settings successfully updated."}, nil
+		},
+	}
+}
