@@ -21,7 +21,7 @@ var logStatusMarshalSpecs = human.EnumMarshalSpecs{
 }
 
 func logPrepareBuilder(c *core.Command) *core.Command {
-	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI any) (any, error) {
 		getResp := respI.(*rdb.PrepareInstanceLogsResponse)
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		readyLogs := make([]*rdb.InstanceLog, len(getResp.InstanceLogs))
