@@ -2,7 +2,7 @@ package tem
 
 import (
 	"github.com/fatih/color"
-	"github.com/scaleway/scaleway-cli/v2/internal/human"
+	"github.com/scaleway/scaleway-cli/v2/core/human"
 	tem "github.com/scaleway/scaleway-sdk-go/api/tem/v1alpha1"
 )
 
