@@ -75,6 +75,14 @@ func createRdbInstance(metaKey, engineName string) core.BeforeFunc {
 	}
 }
 
+func createMongoDBInstance(metaKey string) core.BeforeFunc {
+	return func(ctx *core.BeforeFuncCtx) error {
+		cmd := "scw mongodb instance create node-type=MGDB-PLAY2-NANO name=mongo-cli-test user-name=foobar password={4xdl*#QOoP+&3XRkGA)] endpoints.0.private-network.private-network-id={{ .PN.ID }} --wait"
+
+		return core.ExecStoreBeforeCmd(metaKey, cmd)(ctx)
+	}
+}
+
 func detachRdbInstance() core.AfterFunc {
 	return core.ExecAfterCmd(
 		"scw rdb endpoint delete {{ (index .RDB.Endpoints 0).ID  }} instance-id={{ .RDB.ID }}",
@@ -90,3 +98,19 @@ func waitRdbInstance() core.AfterFunc {
 func deleteRdbInstance() core.AfterFunc {
 	return core.ExecAfterCmd("scw rdb instance delete {{ .RDB.ID }}")
 }
+
+func detachMongoDBInstance() core.AfterFunc {
+	return core.ExecAfterCmd(
+		"scw mongodb endpoint delete {{ (index .mongoDB.Endpoints 0).ID  }}",
+	)
+}
+
+func deleteMongoDBInstance() core.AfterFunc {
+	return core.ExecAfterCmd("scw mongodb instance delete {{ .mongoDB.ID }}")
+}
+
+func waitMongoDBInstance() core.AfterFunc {
+	return core.ExecAfterCmd(
+		"scw mongodb instance wait {{ .mongoDB.ID }}",
+	)
+}
