@@ -8,6 +8,9 @@ import (
 
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
+
+	cmds.MustFind("vpc-gw").Groups = []string{"network"}
+
 	for _, cmd := range cmds.GetAll() {
 		if cmd.Resource == "" || cmd.Verb == "" {
 			continue
@@ -21,8 +24,29 @@ func GetCommands() *core.Commands {
 		cmd.Hidden = true
 	}
 
-	human.RegisterMarshalerFunc(vpcgw.GatewayNetworkStatus(""), human.EnumMarshalFunc(gatewayNetworkStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(vpcgw.GatewayStatus(""), human.EnumMarshalFunc(gatewayStatusMarshalSpecs))
+	cmds.MustFind("vpc-gw").Groups = []string{"network"}
+
+	for _, cmd := range cmds.GetAll() {
+		if cmd.Resource == "" || cmd.Verb == "" {
+			continue
+		}
+		if cmd.Verb == "migrate-to-v2" {
+			continue
+		}
+		if cmd.Resource == "dhcp" || cmd.Resource == "dhcp-entry" {
+			continue
+		}
+		cmd.Hidden = true
+	}
+
+	human.RegisterMarshalerFunc(
+		vpcgw.GatewayNetworkStatus(""),
+		human.EnumMarshalFunc(gatewayNetworkStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		vpcgw.GatewayStatus(""),
+		human.EnumMarshalFunc(gatewayStatusMarshalSpecs),
+	)
 	human.RegisterMarshalerFunc(vpcgw.Gateway{}, gatewayMarshalerFunc)
 	human.RegisterMarshalerFunc(vpcgw.GatewayNetwork{}, gatewayNetworkMarshalerFunc)
 
